//
//  ZMSwitchView.m
//  testDemo
//
//  Created by lm on 2017/5/4.
//  Copyright © 2017年 Czm. All rights reserved.
//

#import "ZMSwitchView.h"

#define SCREEN_WIDTH ([UIScreen mainScreen].bounds.size.width)
#define SCREEN_HEIGHT ([UIScreen mainScreen].bounds.size.height)
#define titleWidth SCREEN_WIDTH/5
#define titleHeight 40
#define backColor [UIColor colorWithWhite:0.300 alpha:1.000]

@interface ZMSwitchView () <UIScrollViewDelegate> {

    UIButton *_selectButton;
    UIView *_sliderView;
    UIScrollView *_titleScroll;
    UIScrollView *_controllerScroll;
}

@property (nonatomic, strong) NSMutableArray<UIButton *> *buttonArray;

@end

@implementation ZMSwitchView



- (instancetype)initWithFrame:(CGRect)frame {

    self = [super initWithFrame:frame];
    if (self) {
        
    }
    return self;
}


- (void)setupTitleScroll
{
    // 创建标题滚动视图
    UIScrollView *scroll = [[UIScrollView alloc] initWithFrame:CGRectMake(0, titleHeight, SCREEN_WIDTH, titleHeight)];
    scroll.contentSize = CGSizeMake(titleWidth * _titleArray.count, titleHeight);
    scroll.bounces = NO;
    scroll.scrollEnabled = YES;
    scroll.showsHorizontalScrollIndicator = NO;
    scroll.showsVerticalScrollIndicator = NO;
    scroll.backgroundColor = [UIColor grayColor];
    [self addSubview:scroll];
    _titleScroll = scroll;
    
    // 创建按钮
    for (int i = 0; i < _titleArray.count; i++)
    {
        UIButton *titleButton = [UIButton buttonWithType:UIButtonTypeCustom];
        titleButton.frame = CGRectMake(titleWidth*i, 0, titleWidth, titleHeight);
        [titleButton setTitle:_titleArray[i] forState:UIControlStateNormal];
        [titleButton setTitleColor:backColor forState:UIControlStateNormal];
        titleButton.titleLabel.font = [UIFont systemFontOfSize:15];
        titleButton.tag = 100+i;
        [titleButton addTarget:self action:@selector(scrollViewSelectToIndex:) forControlEvents:UIControlEventTouchUpInside];
        [scroll addSubview:titleButton];
        [self.buttonArray addObject:titleButton];
        
        // 默认选中第一个按钮
        if (i == 0) {
            _selectButton = titleButton;
            _selectButton.titleLabel.font = [UIFont systemFontOfSize:20];
            [_selectButton setTitleColor:[UIColor redColor] forState:UIControlStateNormal];
        }
    }
    // 滑块
    UIView *sliderV = [[UIView alloc]initWithFrame:CGRectMake(0, titleHeight - 1, titleWidth, 1)];
    sliderV.backgroundColor = [UIColor redColor];
    [scroll addSubview:sliderV];
    _sliderView = sliderV;
    
}

- (void)setupViewControllerScroll
{
    CGFloat scrollView_y = CGRectGetMaxY(_titleScroll.frame);
    UIScrollView *scrollView = [[UIScrollView alloc] initWithFrame:CGRectMake(0, scrollView_y, SCREEN_WIDTH, SCREEN_HEIGHT)];
//    scrollView.backgroundColor = [UIColor yellowColor];
    scrollView.delegate = self;
    scrollView.scrollEnabled = YES;
    scrollView.pagingEnabled = YES;
    scrollView.contentSize = CGSizeMake(SCREEN_WIDTH*_controllerArray.count, SCREEN_HEIGHT-2*titleHeight);
    [self addSubview:scrollView];
    _controllerScroll = scrollView;
    
    for (int i = 0; i < _controllerArray.count; i++) {
        UIView *viewcon = [[UIView alloc] initWithFrame:CGRectMake(SCREEN_WIDTH*i, 0, SCREEN_WIDTH, SCREEN_HEIGHT)];
        UIViewController *viewcontroller = _controllerArray[i];
        viewcon = viewcontroller.view;
        viewcon.frame = CGRectMake(SCREEN_WIDTH*i, 0, SCREEN_WIDTH, SCREEN_HEIGHT);
        viewcon.backgroundColor = [UIColor colorWithRed:arc4random()%255/255.0 green:arc4random()%255/255.0 blue:arc4random()%255/255.0 alpha:1.0];
        [scrollView addSubview:viewcon];
    }
}

// 切换到相应的控制器页面
- (void)scrollViewSelectToIndex:(UIButton *)button
{
    
    NSLog(@"点击了按钮:%ld",button.tag-99);
    [self selectButton:button.tag-100];
    
    // 切换到选中的控制器的view
    [UIView animateWithDuration:0 animations:^{
        _controllerScroll.contentOffset = CGPointMake(SCREEN_WIDTH*(button.tag-100), 0);
    }];
}

//选择某个按钮
- (void)selectButton:(NSInteger)index
{
    // 如果选中其他的按钮，默认按钮回复原来的字体颜色和大小
    [_selectButton setTitleColor:backColor forState:UIControlStateNormal];
    _selectButton.titleLabel.font = [UIFont systemFontOfSize:15];
    
    // 设置选中的按钮
    _selectButton = _buttonArray[index];
    [_selectButton setTitleColor:[UIColor redColor] forState:UIControlStateNormal];
    _selectButton.titleLabel.font = [UIFont systemFontOfSize:20];
    
    // 获取选中按钮的在self.view视图的位置
    CGRect rect = [_selectButton.superview convertRect:_selectButton.frame toView:self];
    [UIView animateWithDuration:0 animations:^{
        // 设置滑片位置
        _sliderView.frame = CGRectMake(titleWidth*index, titleHeight-1, titleWidth, 1);
        // scrollview当前显示区域顶点相对于frame顶点的偏移量
        CGPoint contentOffset = _titleScroll.contentOffset;
        // rect.origin.x + titleWidth/2:选中按钮的中间位置，如果大于屏幕的一半，那么就让按钮居中
        if (contentOffset.x - (SCREEN_WIDTH / 2 - rect.origin.x - titleWidth / 2) <= 0) {
            [_titleScroll setContentOffset:CGPointMake(0, contentOffset.y) animated:YES];
        } else if (contentOffset.x - (SCREEN_WIDTH/2-rect.origin.x - titleWidth / 2) + SCREEN_WIDTH >= _titleArray.count * titleWidth) {
            [_titleScroll setContentOffset:CGPointMake(_titleArray.count * titleWidth - SCREEN_WIDTH, contentOffset.y) animated:YES];
        } else {
            [_titleScroll setContentOffset:CGPointMake(contentOffset.x - (SCREEN_WIDTH / 2 - rect.origin.x - titleWidth/2), contentOffset.y) animated:YES];
        }
    }];
}

//监听滚动事件判断当前拖动到哪一个控制器
-(void)scrollViewDidScroll:(UIScrollView *)scrollView{
    
    if (scrollView == _titleScroll) {
        NSInteger index = scrollView.contentOffset.x / SCREEN_WIDTH;
        [self selectButton:index];
    }
}

#pragma mark - 懒加载
- (NSMutableArray *)buttonArray {
    
    if (_buttonArray == nil) {
        _buttonArray = [NSMutableArray array];
    }
    return _buttonArray;
}

- (void)setTitleArray:(NSArray *)titleArray {

    _titleArray = titleArray;
    [self setupTitleScroll];
}

- (void)setControllerArray:(NSArray *)controllerArray {

    _controllerArray = controllerArray;
    [self setupViewControllerScroll];
}

@end
